use strict;
use HTML::Zoom;
use Test::More;

my $z = HTML::Zoom->from_html(<<'HTML');
<html>
<body>
<div id="foo"><p></p></div>
</body>
</html>
HTML

my @list = qw(foo bar baz);
my $iter = sub { shift @list };

my $actual = $z->select("#foo")->repeat(sub {
    my $e = $iter->() or return;
    return sub {
      $_->select("#foo")->set_attribute({name => 'id', value => $e})
        ->select("p")->replace_content($e);
    };
})->to_html;
my $expected = <<'HTML';
<html>
<body>
<div id="foo"><p>foo</p></div><div id="bar"><p>bar</p></div><div id="baz"><p>baz</p></div>
</body>
</html>
HTML

is($actual, $expected, 'repeat with iterator works');

@list = qw(foo bar baz);
$actual = $z->select("#foo")->repeat([
  map {
    my $e = $_;
    sub {
      $_->select("#foo")->set_attribute({name => 'id', value => $e})
        ->select("p")->replace_content($e);
    }
  } @list
])->to_html;

is($actual, $expected, 'repeat with array of transforms works');

done_testing;
